@@ -4,12 +4,12 @@ use Chart::Gnuplot;
 
 my $chart = Chart::Gnuplot->new(
     output => "gallery/plot3d_3.png",
-    title  => "3D plot from function",
+    title  => "3D plot from data file",
 );
 
 
 my $dataSet = Chart::Gnuplot::DataSet->new(
-    func => "exp(-(x**2 + y**2)/5)",
+    datafile => "plot3d_3.dat",
 );
 
 $chart->plot3d($dataSet);
